@@ -9,8 +9,8 @@
 #include<string.h>
 #include<unistd.h>
 
-#include "file_comp.h"
-#include "almemsys.h"
+#include"file_comp.h"
+#include"../almemsys/almemsys.h"
 
 
 int main(int argc, char * argv[])
