@@ -5,16 +5,19 @@
 #ifndef _SITAR_PROXY_H_
   #define _SITAR_PROXY_H_
 
-  #define CL_VAR "sitar_proxy-1.1.1"
+  #include"config.h"
+
+  #define CL_VAR "sitar_proxy-1.1.13"
 
   #define BUF_LEN 1024
   #define BUF_DEFLEN 128
-  #define BUF_MAX 1048576
+  #define BUF_MAX 1024 * 1024 * 2
 
   #define TIME_LEN 128
+  #define INT_VAL 30
 
   /* debug option */
-  #define DEBUG
+//  #define PROXY_BUG
 
   struct buf_data{
      char ** getdata;
