@@ -11,7 +11,7 @@
 #include<pthread.h>
 
 #include"sitar.h"
-#include"almemsys.h"
+#include<almemsys/almemsys.h>
 
 extern global_data_t gd;
 
