@@ -17,13 +17,7 @@ int fifo_make(char *, int);
 /* --- opt.c --- */
 int optin(int, char *[]);
 
-/* --- tcp.c --- */
-// int socket_connect(int, char []);
-int socket_connect(struct sockaddr_in *, int, char [], int *);
-
 /* --- malloc_set --- */
-// int statfile_malloc(void);
-// int statfile_free(void);
 int scan_malloc_set(private_data_t *);
 int scan_malloc_free(private_data_t *);
 int swap_malloc_set(void);
@@ -36,8 +30,6 @@ int safree(int);
 int sacalloc(int);
 int satmpfree(void);
 int satmpcalloc(void);
-// int samasterfree(void);
-// int samastercalloc(void);
 
 /* --- scan_port.c --- */
 int scan_port(struct scan_buf *);
@@ -49,11 +41,10 @@ int scan_snmp(struct scan_buf *);
 char * stat_check(char *, char *, int, int *);
 
 /* --- times.c --- */
-int time_getr(char [], int);
-long int u_time(void);
-int mail_time_getr(char [], int, char *);
-int ctime_getr(char);
-int hloop(int, int, int);
-int floop(int, int, int, int);
+int hloop(int, int, int, int, int, int);
+int floop(int, int, int, int, int,    int, int, int, int, int);
+
+/* --- time_format.c --- */
+int time_format(char *, int *, int *, int *, int *, int *);
 
 
