@@ -17,10 +17,10 @@
 #include<sys/stat.h>
 #include<errno.h>
 
-#include "sitar_scan.h"
-#include "sitar_com.h"
-#include "almemsys.h"
-#include "jpreturn.h"
+#include"sitar_scan.h"
+#include"sitar_com.h"
+#include<almemsys/almemsys.h>
+#include"jpreturn.h"
 
 
 /* 0-> dhw exc command line 1-> port No' 2-> Ipsddr 3-> return data,, return status code 0=open or=close
