@@ -6,9 +6,9 @@
 #include<string.h>
 #include<stdlib.h>
 
-#include "sitar_scan.h"
-#include "almemsys.h"
-#include "jpreturn.h"
+#include"sitar_scan.h"
+#include<almemsys/almemsys.h>
+#include"jpreturn.h"
 
 
 
