@@ -9,10 +9,10 @@
 #include<string.h>
 
 #include<pthread.h>
-#include "sitar.h"
-#include "sitar_scan.h"
-#include "almemsys.h"
-#include "jpreturn.h"
+#include"sitar.h"
+#include"sitar_scan.h"
+#include<almemsys/almemsys.h>
+#include"jpreturn.h"
 
 /* 0 -> ch_stat       char*  open sccses = 0, not open sccses is !0 
    1 -> ch_prot       char*  for 'TCP,UDP,ICMP'
