@@ -3,7 +3,7 @@
 #include<string.h>
 
 #include"zither_lint.h"
-#include"almemsys.h"
+#include<almemsys/almemsys.h>
 
 int bufinfile(FILE * FP, char *** bufdata, int * lenp)
 {
