@@ -4,7 +4,7 @@
 #include<errno.h>
 
 #include"zither_lint.h"
-#include"almemsys.h"
+#include<almemsys/almemsys.h>
 
 
 int startcheck(int ch, char * data)
