@@ -15,11 +15,11 @@
 #include<pthread.h>
 
 #include"zither.h"
-#include"almemsys.h"
+#include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
 #ifdef POSTGRES_IN
-  #include "/usr/local/pgsql/include/libpq-fe.h"
+  #include<libpq-fe.h>
   extern PGconn * conn;
   extern PGresult * res;
 #endif
@@ -304,7 +304,7 @@ if(((int)neg(pd->rec.user, gd.fp.neg_conf, gd.ms.inip_addr[pd->rec.fdno]))==1){
         gd.ms.inip_addr[pd->rec.fdno][3],
         pd->rec.user,
         "CONNECT",
-        u_time(),
+        (long int)time(NULL),
         ctime_getr('y'),
         ctime_getr('m'),
         ctime_getr('d'),
@@ -719,7 +719,7 @@ printf("LIFE THREAD_TIME_STAT> %s oldtime=%ld in_life=%ld\n", pd->rec.def_user,
 #endif
 
 if(oldtime == pd->life.in_life[0]){
-   intime = u_time();
+   intime = (long int)time(NULL);
    lostime = intime - pd->life.in_life[0];
 
    #ifdef LIFE_DEBUG
